@@ -1,16 +1,16 @@
 ###################################################################################
 # DR DiD estimator with Repeated Cross Section Data
 
-aipw_did_rc1 <- function(y, post, D, ps, out.reg, i.weights){
+aipw_did_rc1 <- function(y, post, D, ps, out.reg, i.weights, trim.ps){
   #-----------------------------------------------------------------------------
   # Compute the AIPW estimator
   # Compute  standardized IPW estimator
   i.weights <- i.weights/mean(i.weights)
 
-  w.treat.pre <- i.weights * D * (1 - post)
-  w.treat.post <- i.weights * D * post
-  w.cont.pre <- i.weights * ps * (1 - D) * (1 - post)/ (1 - ps)
-  w.cont.post  <- i.weights * ps * (1 - D) * post/ (1 - ps)
+  w.treat.pre <- trim.ps * i.weights * D * (1 - post)
+  w.treat.post <- trim.ps * i.weights * D * post
+  w.cont.pre <- trim.ps * i.weights * ps * (1 - D) * (1 - post)/ (1 - ps)
+  w.cont.post  <- trim.ps * i.weights * ps * (1 - D) * post/ (1 - ps)
 
   aipw.1.pre <- mean(w.treat.pre * (y - out.reg)) / mean(w.treat.pre)
   aipw.1.post <- mean(w.treat.post * (y - out.reg)) / mean(w.treat.post)
