@@ -21,6 +21,7 @@ NULL
 #' If \code{boot = TRUE}, default is "weighted".
 #' @param nboot Number of bootstrap repetitions (not relevant if \code{boot = FALSE}). Default is 999.
 #' @param inffunc Logical argument to whether influence function should be returned. Default is FALSE.
+#' @param trim.level The level of trimming for the propensity score. Default is 0.995.
 #'
 #' @return A list containing the following components:
 #' \item{ATT}{The DR DiD point estimate}
@@ -76,7 +77,8 @@ NULL
 
 drdid_imp_rc1 <- function(y, post, D, covariates, i.weights = NULL,
                           boot = FALSE, boot.type =  "weighted", nboot = NULL,
-                          inffunc = FALSE){
+                          inffunc = FALSE,
+                          trim.level = 0.995) {
   #-----------------------------------------------------------------------------
   # D as vector
   D <- as.vector(D)
@@ -105,6 +107,9 @@ drdid_imp_rc1 <- function(y, post, D, covariates, i.weights = NULL,
   pscore.ipt <- pscore.cal(D, int.cov, i.weights = i.weights, n = n)
   ps.fit <- as.vector(pscore.ipt$pscore)
   ps.fit <- pmin(ps.fit, 1 - 1e-6)
+  trim.ps <- (ps.fit < 1.01)
+  trim.ps[D==0] <- (ps.fit[D==0] < trim.level)
+
   #Compute the Outcome regression for the control group
   out.y.pre <- wols_rc(y, post, D, int.cov, ps.fit, i.weights, pre = TRUE, treat = FALSE)
   out.y.pre <-  as.vector(out.y.pre$out.reg)
@@ -114,10 +119,10 @@ drdid_imp_rc1 <- function(y, post, D, covariates, i.weights = NULL,
   out.y <- post * out.y.post + (1 - post) * out.y.pre
   #-----------------------------------------------------------------------------
   # First, the weights
-  w.treat.pre <- i.weights * D * (1 - post)
-  w.treat.post <- i.weights * D * post
-  w.cont.pre <- i.weights * ps.fit * (1 - D) * (1 - post)/(1 - ps.fit)
-  w.cont.post <- i.weights * ps.fit * (1 - D) * post/(1 - ps.fit)
+  w.treat.pre <- trim.ps * i.weights * D * (1 - post)
+  w.treat.post <- trim.ps *  i.weights * D * post
+  w.cont.pre <- trim.ps *  i.weights * ps.fit * (1 - D) * (1 - post)/(1 - ps.fit)
+  w.cont.post <- trim.ps * i.weights * ps.fit * (1 - D) * post/(1 - ps.fit)
 
   # Elements of the influence function (summands)
   eta.treat.pre <- w.treat.pre * (y - out.y) / mean(w.treat.pre)
@@ -183,7 +188,8 @@ drdid_imp_rc1 <- function(y, post, D, covariates, i.weights = NULL,
       # do weighted bootstrap
       dr.boot <- unlist(lapply(1:nboot, wboot_drdid_imp_rc1,
                                n = n, y = y, post = post,
-                               D = D, int.cov = int.cov, i.weights = i.weights))
+                               D = D, int.cov = int.cov, i.weights = i.weights,
+                               trim.level = trim.level))
       # get bootstrap std errors based on IQR
       se.dr.att <- stats::IQR((dr.boot - dr.att)) / (stats::qnorm(0.75) - stats::qnorm(0.25))
       # get symmtric critival values
@@ -211,7 +217,8 @@ drdid_imp_rc1 <- function(y, post, D, covariates, i.weights = NULL,
     boot = boot,
     boot.type = boot.type,
     nboot = nboot,
-    type = "dr"
+    type = "dr",
+    trim.level = trim.level
   )
   ret <- (list(ATT = dr.att,
                se = se.dr.att,
